Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(141)

Unified Diff: pkg/analysis_server/lib/plugin/assist.dart

Issue 1073383002: Create a public API for contributing assists and make assists pluggable (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/plugin/assist.dart
diff --git a/pkg/analysis_server/lib/plugin/fix.dart b/pkg/analysis_server/lib/plugin/assist.dart
similarity index 60%
copy from pkg/analysis_server/lib/plugin/fix.dart
copy to pkg/analysis_server/lib/plugin/assist.dart
index a89b84738cb5957ee1afd190df31dd8553c88791..cc037f6b087576f8b012c42a6b767dd37be074f3 100644
--- a/pkg/analysis_server/lib/plugin/fix.dart
+++ b/pkg/analysis_server/lib/plugin/assist.dart
@@ -3,20 +3,20 @@
// BSD-style license that can be found in the LICENSE file.
/**
* Support for client code that extends the analysis server by adding new fix
* contributors.
*/
-library analysis_server.plugin.fix;
+library analysis_server.plugin.assist;
-import 'package:analysis_server/edit/fix/fix_core.dart';
+import 'package:analysis_server/edit/assist/assist_core.dart';
import 'package:analysis_server/src/plugin/server_plugin.dart';
import 'package:analyzer/plugin/plugin.dart';
/**
* The identifier of the extension point that allows plugins to register new
* fix contributors with the server. The object used as an extension must be a
* [FixContributor].
*/
-final String FIX_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
+final String ASSIST_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
ServerPlugin.UNIQUE_IDENTIFIER,
- ServerPlugin.FIX_CONTRIBUTOR_EXTENSION_POINT);
+ ServerPlugin.ASSIST_CONTRIBUTOR_EXTENSION_POINT);

Powered by Google App Engine
This is Rietveld 408576698
@@ -3,20 +3,20 @@
// BSD-style license that can be found in the LICENSE file.
/**
- * Support for client code that extends the analysis server by adding new fix
+ * Support for client code that extends the analysis server by adding new assist
* contributors.
*/
@@ -3,20 +3,20 @@
/**
* The identifier of the extension point that allows plugins to register new
- * fix contributors with the server. The object used as an extension must be a
- * [FixContributor].
+ * assist contributors with the server. The object used as an extension must be
+ * an [AssistContributor].
*/